==> cognito-1.60.0-sources.jar: software/amazon/awscdk/services/cognito/SignInUrlOptions.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Options to customize the behaviour of `signInUrl()`.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.712Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.SignInUrlOptions")
@software.amazon.jsii.Jsii.Proxy(SignInUrlOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SignInUrlOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Where to redirect to after sign in.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getRedirectUri();

    /**
     * The path in the URI where the sign-in page is located.
     * <p>
     * Default: '/login'
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSignInPath() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SignInUrlOptions> {
        private java.lang.String redirectUri;
        private java.lang.String signInPath;

        /**
         * Sets the value of {@link SignInUrlOptions#getRedirectUri}
         * @param redirectUri Where to redirect to after sign in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder redirectUri(java.lang.String redirectUri) {
            this.redirectUri = redirectUri;
            return this;
        }

        /**
         * Sets the value of {@link SignInUrlOptions#getSignInPath}
         * @param signInPath The path in the URI where the sign-in page is located.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder signInPath(java.lang.String signInPath) {
            this.signInPath = signInPath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SignInUrlOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SignInUrlOptions build() {
            return new Jsii$Proxy(redirectUri, signInPath);
        }
    }

    /**
     * An implementation for {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SignInUrlOptions {
        private final java.lang.String redirectUri;
        private final java.lang.String signInPath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.redirectUri = this.jsiiGet("redirectUri", java.lang.String.class);
            this.signInPath = this.jsiiGet("signInPath", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String redirectUri, final java.lang.String signInPath) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.redirectUri = java.util.Objects.requireNonNull(redirectUri, "redirectUri is required");
            this.signInPath = signInPath;
        }

        @Override
        public java.lang.String getRedirectUri() {
            return this.redirectUri;
        }

        @Override
        public java.lang.String getSignInPath() {
            return this.signInPath;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("redirectUri", om.valueToTree(this.getRedirectUri()));
            if (this.getSignInPath() != null) {
                data.set("signInPath", om.valueToTree(this.getSignInPath()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.SignInUrlOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SignInUrlOptions.Jsii$Proxy that = (SignInUrlOptions.Jsii$Proxy) o;

            if (!redirectUri.equals(that.redirectUri)) return false;
            return this.signInPath != null ? this.signInPath.equals(that.signInPath) : that.signInPath == null;
        }

        @Override
        public int hashCode() {
            int result = this.redirectUri.hashCode();
            result = 31 * result + (this.signInPath != null ? this.signInPath.hashCode() : 0);
            return result;
        }
    }
}

==> cognito-1.93.0-sources.jar: software/amazon/awscdk/services/cognito/SignInUrlOptions.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Options to customize the behaviour of `signInUrl()`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.485Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.SignInUrlOptions")
@software.amazon.jsii.Jsii.Proxy(SignInUrlOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SignInUrlOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Where to redirect to after sign in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRedirectUri();

    /**
     * The path in the URI where the sign-in page is located.
     * <p>
     * Default: '/login'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSignInPath() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SignInUrlOptions> {
        private java.lang.String redirectUri;
        private java.lang.String signInPath;

        /**
         * Sets the value of {@link SignInUrlOptions#getRedirectUri}
         * @param redirectUri Where to redirect to after sign in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder redirectUri(java.lang.String redirectUri) {
            this.redirectUri = redirectUri;
            return this;
        }

        /**
         * Sets the value of {@link SignInUrlOptions#getSignInPath}
         * @param signInPath The path in the URI where the sign-in page is located.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signInPath(java.lang.String signInPath) {
            this.signInPath = signInPath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SignInUrlOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SignInUrlOptions build() {
            return new Jsii$Proxy(redirectUri, signInPath);
        }
    }

    /**
     * An implementation for {@link SignInUrlOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SignInUrlOptions {
        private final java.lang.String redirectUri;
        private final java.lang.String signInPath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.redirectUri = software.amazon.jsii.Kernel.get(this, "redirectUri", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.signInPath = software.amazon.jsii.Kernel.get(this, "signInPath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String redirectUri, final java.lang.String signInPath) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.redirectUri = java.util.Objects.requireNonNull(redirectUri, "redirectUri is required");
            this.signInPath = signInPath;
        }

        @Override
        public final java.lang.String getRedirectUri() {
            return this.redirectUri;
        }

        @Override
        public final java.lang.String getSignInPath() {
            return this.signInPath;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("redirectUri", om.valueToTree(this.getRedirectUri()));
            if (this.getSignInPath() != null) {
                data.set("signInPath", om.valueToTree(this.getSignInPath()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.SignInUrlOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SignInUrlOptions.Jsii$Proxy that = (SignInUrlOptions.Jsii$Proxy) o;

            if (!redirectUri.equals(that.redirectUri)) return false;
            return this.signInPath != null ? this.signInPath.equals(that.signInPath) : that.signInPath == null;
        }

        @Override
        public final int hashCode() {
            int result = this.redirectUri.hashCode();
            result = 31 * result + (this.signInPath != null ? this.signInPath.hashCode() : 0);
            return result;
        }
    }
}
